Description Usage Arguments Value Examples
Plots a traceplot for the different MCMC chains of a micore object
for a specific parameter.
1 2 3 4 5 6 7 8 |
obj |
An object of class |
par |
Character object specifying which parameter to make a traceplot for. |
ind |
For matrix parameters, a 2-dimensional vector specifying the element of the parameter matrix to make the traceplot for. |
xlab |
Label for the x-axis. |
ylab |
Label for the y-axis. |
... |
Other arguments passed to |
Makes a traceplot for the specified parameter.
1 2 3 4 5 6 7 8 9 10 11 12 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.